[data-md-color-scheme="default"] {
    --md-primary-fg-color: #1b5e20;
    --md-primary-fg-color--light: #2e7d32;
    --md-primary-fg-color--dark: #1b5e20;
    --md-accent-fg-color: #1b5e20;
    --md-accent-fg-color--transparent: rgba(27, 94, 32, 0.1);
}

[data-md-color-scheme="slate"] {
    --md-primary-fg-color: #000000;
    --md-primary-fg-color--light: #1a1a1a;
    --md-primary-fg-color--dark: #000000;
    --md-accent-fg-color: #00bcd4;
    --md-accent-fg-color--transparent: rgba(0, 188, 212, 0.1);
}
