from odoo.addons import src_layout
from odoo.tests import TransactionCase
from odoo.tools import file_path


class TestSrcLayout(TransactionCase):
    def test_module_importable(self):
        self.assertTrue(src_layout.found)

    def test_file_path(self):
        self.assertTrue(
            file_path("src_layout/tests/__init__.py").endswith(
                "/odoo/addons/src_layout/tests/__init__.py"
            )
        )
